Module write

Module write 

Write and vectored-write operation handlers.

Functions

execute_write
Execute a positional write at offset, returning the buffer and the number of bytes written.
execute_write_vectored
Execute a positional vectored write at offset over buffers, returning the completed buffers and the total number of bytes written.