pub fn execute_write_vectored(
file: File,
offset: u64,
buffers: Vec<Buffer<Submitted>>,
) -> Result<CompletionPayload>Expand description
Execute a positional vectored write at offset over buffers,
returning the completed buffers and the total number of bytes written.