pub struct FallbackBackend { /* private fields */ }Expand description
Blocking worker backend.
Implementations
Sourceimpl FallbackBackend
impl FallbackBackend
Sourcepub fn new(
config: &RingConfig,
completion_tx: Sender<BackendCompletion>,
) -> Result<Self>
pub fn new( config: &RingConfig, completion_tx: Sender<BackendCompletion>, ) -> Result<Self>
Creates a fallback backend with the configured worker count.
Errors
Returns an error if the completion channel sender cannot be cloned or worker thread spawning fails.